/*
 * test-blob.cc
 *
 * Copyright (C) 2015 Tim Marston <tim@ed.am>
 *
 * This file is part of sqlite3cc (hereafter referred to as "this program").
 * See http://ed.am/dev/sqlite3cc for more information.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <sqlite3cc.h>
#include <boost/filesystem.hpp>


#define DBFILE "blob.db"


int main()
{
	// delete any existing test database
	if( boost::filesystem::exists( DBFILE ) )
		boost::filesystem::remove( DBFILE );

	// open database
	sqlite::connection conn( DBFILE );

	std::cout << "SQLite threading mode: " << sqlite::threadsafe() << "\n";

	// set up database
	sqlite::command c1( conn,
		"CREATE TABLE test ( "
			"name TEXT PRIMARY KEY, "
			"data BLOB NOT NULL "
		")" );
	c1.exec();

	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

	// insert data in to blob
	char data[] = {
		'h', 'e', 'l', 'l', 'o', 0,
		't', 'h', 'e', 'r', 'e'
	};
	std::string str( data, sizeof( data ) );
	size_t length = str.length();
	std::cout << "data size: " << length << " chars\n";
	sqlite::command( conn, "INSERT INTO test VALUES( ?, ? )" )
		<< "test" << sqlite::blob( str ) << sqlite::exec;

	// check that it is stored in its entirety
	sqlite::query q1( conn, "SELECT length( data ) FROM test" );
	assert( q1.step().column< int >( 0 ) == length );

	// retrieve data from blob
	sqlite::query q2( conn, "SELECT data FROM test" );
	std::string str2 = q2.step().column< std::string >( 0 );
	assert( str2 == str );

	return 0;
}
